@@ -29,8 +29,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import JobStatusType
 from .type_defs import (
@@ -62,7 +61,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeComputeEnvironmentsPaginator(Boto3Paginator):
+class DescribeComputeEnvironmentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Paginator.DescribeComputeEnvironments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators/#describecomputeenvironmentspaginator)
@@ -80,7 +79,7 @@ class DescribeComputeEnvironmentsPaginator(Boto3Paginator):
         """
 
 
-class DescribeJobDefinitionsPaginator(Boto3Paginator):
+class DescribeJobDefinitionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Paginator.DescribeJobDefinitions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators/#describejobdefinitionspaginator)
@@ -100,7 +99,7 @@ class DescribeJobDefinitionsPaginator(Boto3Paginator):
         """
 
 
-class DescribeJobQueuesPaginator(Boto3Paginator):
+class DescribeJobQueuesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Paginator.DescribeJobQueues)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators/#describejobqueuespaginator)
@@ -115,7 +114,7 @@ class DescribeJobQueuesPaginator(Boto3Paginator):
         """
 
 
-class ListJobsPaginator(Boto3Paginator):
+class ListJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Paginator.ListJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators/#listjobspaginator)
@@ -137,7 +136,7 @@ class ListJobsPaginator(Boto3Paginator):
         """
 
 
-class ListSchedulingPoliciesPaginator(Boto3Paginator):
+class ListSchedulingPoliciesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html#Batch.Paginator.ListSchedulingPolicies)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_batch/paginators/#listschedulingpoliciespaginator)
