@@ -1704,6 +1704,8 @@ _OptionalJobDetailTypeDef = TypedDict(
         "platformCapabilities": List[PlatformCapabilityType],
         "eksProperties": EksPropertiesDetailTypeDef,
         "eksAttempts": List[EksAttemptDetailTypeDef],
+        "isCancelled": bool,
+        "isTerminated": bool,
     },
     total=False,
 )
